==> tcpreplay_4.4.3.orig.tar.xz: tcpreplay-4.4.3/src/common.h <==
/* $Id$ */

/*
 *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
 *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
 *
 *   The Tcpreplay Suite of tools is free software: you can redistribute it 
 *   and/or modify it under the terms of the GNU General Public License as 
 *   published by the Free Software Foundation, either version 3 of the 
 *   License, or with the authors permission any later version.
 *
 *   The Tcpreplay Suite is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef __COMMON_H__
#define __COMMON_H__
#include <assert.h>
#include "config.h"

#ifdef __cplusplus
extern "C" {
#endif

#include "common/pcap_dlt.h"
#include "common/cache.h"
#include "common/cidr.h"
#include "common/err.h"
#include "common/get.h"
#include "common/fakepcap.h"
#include "common/fakepcapnav.h"
#include "common/fakepoll.h"
#include "common/list.h"
#include "common/mac.h"
#include "common/services.h"
#include "common/utils.h"
#include "common/xX.h"
#include "common/tcpdump.h"
#include "common/timer.h"
#include "common/sendpacket.h"
#include "common/interface.h"
#include "common/flows.h"

const char *git_version(void); /* git_version.c */

#ifdef __cplusplus
}
#endif

#endif

==> tcpreplay_4.4.4.orig.tar.xz: tcpreplay-4.4.4/src/common.h <==
/* $Id$ */

/*
 *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
 *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
 *
 *   The Tcpreplay Suite of tools is free software: you can redistribute it
 *   and/or modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation, either version 3 of the
 *   License, or with the authors permission any later version.
 *
 *   The Tcpreplay Suite is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "config.h"
#include <assert.h>

#ifdef __cplusplus
extern "C" {
#endif

#include <common/cache.h>
#include <common/cidr.h>
#include <common/err.h>
#include <common/fakepcap.h>
#include <common/fakepcapnav.h>
#include <common/fakepoll.h>
#include <common/flows.h>
#include <common/get.h>
#include <common/interface.h>
#include <common/list.h>
#include <common/mac.h>
#include <common/pcap_dlt.h>
#include <common/sendpacket.h>
#include <common/services.h>
#include <common/tcpdump.h>
#include <common/timer.h>
#include <common/utils.h>
#include <common/xX.h>

const char *git_version(void); /* git_version.c */

#ifdef __cplusplus
}
#endif
